@@ -71,8 +71,7 @@ sub _generateSingle {
 	my $args	= {@_};
 	my $model	= $args->{model};
 	my $mode	= $args->{mode};
-	my $module	= $args->{module};
-	my $class_prefix = $args->{class_prefix};	
+	my $module	= $args->{module};	
 	my $code	= $self->_fabricatePrelude(@_);	
 	my $destination		= $args->{destination} || '/tmp/lib/perl/';
 	my $verbose	= $self->{verbose} || 0;
@@ -97,11 +96,9 @@ sub _generateSingle {
 		return $code;
 	}else { 
 		# generate module
-		$destination .= '/' if ($destination && ($destination !~ /\/$/));
-		$class_prefix .= '::' if ($class_prefix && ($class_prefix !~ /::$/));		
+		$destination .= '/' unless ($destination =~ /\/$/);		
 		my $file	= $module or  die "Pastor:Generator:_generateSingle:A 'module' name is required!\n"; 
-		
-		$file 		= $destination .  $file . '.pm';	
+		$file 		= $destination . $file . '.pm';	
 		$file 		=~ s/::/\//g;		
 		$self->_writeCode(@_, file=>$file, code=>$code);	
 	}
@@ -117,7 +114,7 @@ sub _generateMultiple {
 	my $model	= $args->{model};
 	my $types	= $model->type();
 	my $destination		= $args->{destination} || '/tmp/lib/perl/';
-	$destination .= '/' if ($destination && ($destination !~ /\/$/));
+	$destination .= '/' unless ($destination =~ /\/$/);
 	
 	foreach my $items ($model->type(), 	$model->element()) {
 		foreach my $name (sort keys %$items) {
@@ -141,12 +138,9 @@ sub _fabricatePrelude {
 	my $self 	= shift;
 	my $code = "";
 	
-	$code .= "\n#PASTOR: Code generated by XML::Pastor/" . $XML::Pastor::VERSION . " at '" . localtime() . "'\n";
+	$code .= "\n# Code generated by XML::Pastor at '" . localtime() . "'\n";
 	$code .= "\nuse utf8;";
-	$code .= "\nuse strict;";	
-#	$code .= "\nuse warnings;";
-#	$code .= "\nno warnings qw(uninitialized);";
-
+	$code .= "\nuse strict;";		
 	$code .= "\n\nuse XML::Pastor;\n\n";	
 	return $code;	
 }
@@ -190,10 +184,7 @@ sub _fabricateCode {
 	# mk_accessors			
 	my $accessors = [];
 	if (UNIVERSAL::can($object, "attributes")) {
-		my $attribPfx = "";
-		$attribPfx = $object->attributePrefix() if (UNIVERSAL::can($object, "attributePrefix"));
-		my $fields = [map {$attribPfx . $_} @{$object->attributes()}]; 
-		push @$accessors, @$fields;
+		push @$accessors, @{$object->attributes()};
 	}
 	if (UNIVERSAL::can($object, "elements")) {
 		push @$accessors, @{$object->elements()};
@@ -201,27 +192,6 @@ sub _fabricateCode {
 	if ( scalar(@$accessors) ) {
 		$code .= "\n\n$class". '->mk_accessors( qw(' . join (' ', @$accessors) . "));";
 	}
-
-	
-	# Attribute accessor aliases
-	if (UNIVERSAL::can($object, "attributes")) {
-		my $attributes = $object->attributes(); 
-		my $attribPfx 	= (UNIVERSAL::can($object, "attributePrefix")) ? $object->attributePrefix() : "";
-		
-		if (scalar(@$attributes) && $attribPfx) {
-			$code .= "\n\n# Attribute accessor aliases\n";
-			my $elementInfo	= (UNIVERSAL::can($object, "effectiveElementInfo")) ? $object->effectiveElementInfo() : {};		
-			foreach my $attribute (@$attributes) {
-				next if defined($elementInfo->{$attribute});		# Attribute/Element name conflict. No alias possible
-				my $field = $attribPfx . $attribute;
-				next if ($field eq $attribute);					# No attribute prefix. No need for an alias.
-				$code .= "\nsub $attribute { &" . $field . '; }';
-			}		
-						
-		}
-		
-	}
-	
 	
 	# XmlSchemaInfo	
 	if (UNIVERSAL::isa($object, "XML::Pastor::Schema::Element")) {
@@ -258,9 +228,8 @@ sub _calculateUses {
 		# Consider the class as 'used' unless it starts with XML::Pastor which is handled differently
 		# But XML::Pastor::Test::* are used for testing purposes. 
 		SWITCH: {
-			(($class =~ /^XML::Pastor::/) && 
-			($class !~ /^XML::Pastor::Test/))				and do {last SWITCH;};
-			OTHERWISE:										{ $result->{$class}=1; last SWITCH;}			
+			$class =~ /^XML::Pastor::Test/			and do {$result->{$class} = 1; last SWITCH;};
+			$class =~ /^XML::Pastor::/				and do {last SWITCH;};			
 		}		
 		
 	}
@@ -271,10 +240,8 @@ sub _calculateUses {
 		# Consider the class as 'used' unless it starts with XML::Pastor which is handled differently
 		# But XML::Pastor::Test::* are used for testing purposes. 
 		SWITCH: {
-			(($class =~ /^XML::Pastor::/) && 
-			($class !~ /^XML::Pastor::Test/))				and do {last SWITCH;};
-			OTHERWISE:										{ $result->{$class}=1; last SWITCH;}			
-						
+			$class =~ /^XML::Pastor::Test/			and do {$result->{$class} = 1; last SWITCH;};
+			$class =~ /^XML::Pastor::/				and do {last SWITCH;};			
 		}		
 		
 	}
@@ -285,23 +252,20 @@ sub _calculateUses {
 			# Consider the class as 'used' unless it starts with XML::Pastor which is handled differently
 			# But XML::Pastor::Test::* are used for testing purposes. 
 			SWITCH: {
-				(($class =~ /^XML::Pastor::/) && 
-				($class !~ /^XML::Pastor::Test/))				and do {last SWITCH;};
-				OTHERWISE:										{ $result->{$class}=1; last SWITCH;}							
+				$class =~ /^XML::Pastor::Test/			and do {$result->{$class} = 1; last SWITCH;};
+				$class =~ /^XML::Pastor::/				and do {last SWITCH;};			
 			}		
 		}
 	}
 
-	if (UNIVERSAL::can($object, "memberClasses") && $object->memberClasses()) {
+	if (UNIVERSAL::can($object, "memberClasses") && $object->baseClasses()) {
 		my $mbcs = $object->memberClasses();
 		foreach my $class (@$mbcs) {		
 			# Consider the class as 'used' unless it starts with XML::Pastor which is handled differently
 			# But XML::Pastor::Test::* are used for testing purposes. 
 			SWITCH: {
-				(($class =~ /^XML::Pastor::/) && 
-				($class !~ /^XML::Pastor::Test/))				and do {last SWITCH;};
-				OTHERWISE:										{ $result->{$class}=1; last SWITCH;}			
-				
+				$class =~ /^XML::Pastor::Test/			and do {$result->{$class} = 1; last SWITCH;};
+				$class =~ /^XML::Pastor::/				and do {last SWITCH;};			
 			}		
 		}
 	}
